==> dokuwiki-2011.05.25a.tgz: dokuwiki/lib/plugins/plugin/lang/fr/lang.php <==
<?php
/**
 * french language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Guy Brand <gb@isis.u-strasbg.fr>
 * @author Delassaux Julien <julien@delassaux.fr>
 * @author Maurice A. LeBlanc <leblancma@cooptel.qc.ca>
 * @author gb@isis.u-strasbg.fr
 * @author stephane.gully@gmail.com
 * @author Guillaume Turri <guillaume.turri@gmail.com>
 * @author Erik Pedersen <erik.pedersen@shaw.ca>
 * @author olivier duperray <duperray.olivier@laposte.net>
 * @author Vincent Feltz <psycho@feltzv.fr>
 * @author Philippe Bajoit <philippe.bajoit@gmail.com>
 * @author Florian Gaub <floriang@floriang.net>
 * @author Samuel Dorsaz samuel.dorsaz@novelion.net
 * @author Johan Guilbaud <guilbaud.johan@gmail.com>
 */
$lang['menu']                  = 'Gestion des modules externes';
$lang['download']              = 'Télécharger et installer un nouveau module';
$lang['manage']                = 'Modules installés';
$lang['btn_info']              = 'Info';
$lang['btn_update']            = 'Mettre à jour';
$lang['btn_delete']            = 'Supprimer';
$lang['btn_settings']          = 'Paramètres';
$lang['btn_download']          = 'Télécharger';
$lang['btn_enable']            = 'Enregistrer';
$lang['url']                   = 'URL';
$lang['installed']             = 'Installé :';
$lang['lastupdate']            = 'Dernière mise à jour :';
$lang['source']                = 'Source :';
$lang['unknown']               = 'inconnu';
$lang['updating']              = 'Mise à jour…';
$lang['updated']               = 'Modules %s mis à jour avec succès';
$lang['updates']               = 'Les modules suivants ont été mis à jour avec succès';
$lang['update_none']           = 'Aucune mise à jour n\'a été trouvée.';
$lang['deleting']              = 'Suppression…';
$lang['deleted']               = 'Module %s supprimé.';
$lang['downloading']           = 'Téléchargement…';
$lang['downloaded']            = 'Module %s installé avec succès';
$lang['downloads']             = 'Les modules suivants ont été installés avec succès :';
$lang['download_none']         = 'Aucun module n\'était trouvé, ou un problème inconnu est survenu durant le téléchargement et l\'installation.';
$lang['plugin']                = 'Module :';
$lang['components']            = 'Composants';
$lang['noinfo']                = 'Ce module externe n\'a transmis aucune information, il pourrait être invalide.';
$lang['name']                  = 'Nom :';
$lang['date']                  = 'Date :';
$lang['type']                  = 'Type :';
$lang['desc']                  = 'Description :';
$lang['author']                = 'Auteur :';
$lang['www']                   = 'Site web :';
$lang['error']                 = 'Une erreur inconnue est survenue.';
$lang['error_download']        = 'Impossible de télécharger le fichier du module : %s';
$lang['error_badurl']          = 'URL suspecte. Impossible de déterminer le nom du fichier à partir de l\'URL';
$lang['error_dircreate']       = 'Impossible de créer le répertoire temporaire pour réceptionner le téléchargement';
$lang['error_decompress']      = 'Le gestionnaire de modules externes a été incapable de décompresser le fichier téléchargé. Ceci peut être le résultat d\'un mauvais téléchargement, auquel cas vous devriez réessayer ; ou bien le format de compression est inconnu, auquel cas vous devez télécharger et installer le module manuellement.';
$lang['error_copy']            = 'Une erreur de copie est survenue lors de l\'installation des fichiers du module <em>%s</em> : votre disque est peut-être plein ou les droits d\'accès au fichier sont incorrects. Il a pu en résulter une installation partielle du module rendant votre installation du wiki instable.';
$lang['error_delete']          = 'Une erreur est survenue à la suppression du module <em>%s</em>.  La raison la plus probable est l\'insuffisance des droits sur les fichiers ou le répertoire.';
$lang['enabled']               = 'Module %s activé.';
$lang['notenabled']            = 'Le module %s n\'a pas pu être activé, vérifiez le fichier des permissions.';
$lang['disabled']              = 'Module %s désactivé.';
$lang['notdisabled']           = 'Le module %s n\'a pas pu être désactivé, vérifiez le fichier des permissions.';
$lang['packageinstalled']      = 'Ensemble de modules (%d module%s: %s) installé avec succès.';

==> dokuwiki-2012.01.25.tgz: dokuwiki/lib/plugins/plugin/lang/fr/lang.php <==
<?php
/**
 * french language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Guy Brand <gb@unistra.fr>
 * @author Delassaux Julien <julien@delassaux.fr>
 * @author Maurice A. LeBlanc <leblancma@cooptel.qc.ca>
 * @author stephane.gully@gmail.com
 * @author Guillaume Turri <guillaume.turri@gmail.com>
 * @author Erik Pedersen <erik.pedersen@shaw.ca>
 * @author olivier duperray <duperray.olivier@laposte.net>
 * @author Vincent Feltz <psycho@feltzv.fr>
 * @author Philippe Bajoit <philippe.bajoit@gmail.com>
 * @author Florian Gaub <floriang@floriang.net>
 * @author Samuel Dorsaz samuel.dorsaz@novelion.net
 * @author Johan Guilbaud <guilbaud.johan@gmail.com>
 * @author schplurtz@laposte.net
 * @author skimpax@gmail.com
 */
$lang['menu']                  = 'Gestion des modules externes';
$lang['download']              = 'Télécharger et installer un nouveau module';
$lang['manage']                = 'Modules installés';
$lang['btn_info']              = 'Info';
$lang['btn_update']            = 'Mettre à jour';
$lang['btn_delete']            = 'Supprimer';
$lang['btn_settings']          = 'Paramètres';
$lang['btn_download']          = 'Télécharger';
$lang['btn_enable']            = 'Enregistrer';
$lang['url']                   = 'URL';
$lang['installed']             = 'Installé :';
$lang['lastupdate']            = 'Dernière mise à jour :';
$lang['source']                = 'Source :';
$lang['unknown']               = 'inconnu';
$lang['updating']              = 'Mise à jour…';
$lang['updated']               = 'Modules %s mis à jour avec succès';
$lang['updates']               = 'Les modules suivants ont été mis à jour avec succès';
$lang['update_none']           = 'Aucune mise à jour n\'a été trouvée.';
$lang['deleting']              = 'Suppression…';
$lang['deleted']               = 'Module %s supprimé.';
$lang['downloading']           = 'Téléchargement…';
$lang['downloaded']            = 'Module %s installé avec succès';
$lang['downloads']             = 'Les modules suivants ont été installés avec succès :';
$lang['download_none']         = 'Aucun module n\'était trouvé, ou un problème inconnu est survenu durant le téléchargement et l\'installation.';
$lang['plugin']                = 'Module :';
$lang['components']            = 'Composants';
$lang['noinfo']                = 'Ce module externe n\'a transmis aucune information, il pourrait être invalide.';
$lang['name']                  = 'Nom :';
$lang['date']                  = 'Date :';
$lang['type']                  = 'Type :';
$lang['desc']                  = 'Description :';
$lang['author']                = 'Auteur :';
$lang['www']                   = 'Site web :';
$lang['error']                 = 'Une erreur inconnue est survenue.';
$lang['error_download']        = 'Impossible de télécharger le fichier du module : %s';
$lang['error_badurl']          = 'URL suspecte. Impossible de déterminer le nom du fichier à partir de l\'URL';
$lang['error_dircreate']       = 'Impossible de créer le répertoire temporaire pour réceptionner le téléchargement';
$lang['error_decompress']      = 'Le gestionnaire de modules externes a été incapable de décompresser le fichier téléchargé. Ceci peut être le résultat d\'un mauvais téléchargement, auquel cas vous devriez réessayer ; ou bien le format de compression est inconnu, auquel cas vous devez télécharger et installer le module manuellement.';
$lang['error_copy']            = 'Une erreur de copie est survenue lors de l\'installation des fichiers du module <em>%s</em> : votre disque est peut-être plein ou les droits d\'accès au fichier sont incorrects. Il a pu en résulter une installation partielle du module rendant votre installation du wiki instable.';
$lang['error_delete']          = 'Une erreur est survenue à la suppression du module <em>%s</em>.  La raison la plus probable est l\'insuffisance des droits sur les fichiers ou le répertoire.';
$lang['enabled']               = 'Module %s activé.';
$lang['notenabled']            = 'Le module %s n\'a pas pu être activé, vérifiez le fichier des permissions.';
$lang['disabled']              = 'Module %s désactivé.';
$lang['notdisabled']           = 'Le module %s n\'a pas pu être désactivé, vérifiez le fichier des permissions.';
$lang['packageinstalled']      = 'Ensemble de modules (%d module(s): %s) installé avec succès.';
